@@ -1,4 +1,6 @@
 // [[Rcpp::plugins(cpp11)]]
+#define STRICT_R_HEADERS
+#include <cfloat>
 #include <Rcpp.h>
 using namespace Rcpp ;
 
