@@ -1,5 +1,7 @@
 // [[Rcpp::plugins(cpp11)]]
 #include <numeric>
+#define STRICT_R_HEADERS
+#include <cfloat>
 #include <Rcpp.h>
 using namespace Rcpp;
 
